/*
	JAHIDDevice.h
	
	Abstract class representing an IOKit HID device. Different implementations
	are used on different version of Mac OS X.
	
	
	Copyright © 2008 Jens Ayton

	Permission is hereby granted, free of charge, to any person obtaining a
	copy of this software and associated documentation files (the “Software”),
	to deal in the Software without restriction, including without limitation
	the rights to use, copy, modify, merge, publish, distribute, sublicense,
	and/or sell copies of the Software, and to permit persons to whom the
	Software is furnished to do so, subject to the following conditions:
	
	The above copyright notice and this permission notice shall be included in
	all copies or substantial portions of the Software.

	THE SOFTWARE IS PROVIDED “AS IS”, WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
	IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
	FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
	THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
	LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
	FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
	DEALINGS IN THE SOFTWARE.
*/

#import <JAHIDDevices/JAHIDElementCollection.h>


@interface JAHIDDevice: JAHIDElementCollection

/*!	@method		allDevices
	@abstract	Returns the set of all devices currently connected.
*/
+ (NSSet *) allDevices;

/*!	@method		manufacturerName
	@abstract	Returns the device's manufacturer name.
*/
- (NSString *) manufacturerName;

/*!	@method		productName
	@abstract	Returns the device's product name.
*/
- (NSString *) productName;

/*!	@method		vendorID
	@abstract	Returns the device's vendor ID.
	@discussion	The vendor ID identifies the manufacturer of the device.
*/
- (JAHIDVendorID) vendorID;

/*!	@method		productID
	@abstract	Returns the device's product ID.
	@discussion	If non-zero, the product ID, together with the vendor ID,
				uniquely identifies the device type. Non-zero product IDs can
				occur; for instance, the product ID 0 with the vendor ID 1452
				is used for ADB devices.
*/
- (JAHIDProductID) productID;

/*!	@method		serialNumber
	@abstract	Returns the device's serial number, if available.
*/
- (NSString *) serialNumber;

/*!	@method		countryCode
	@abstract	Returns the device's country code, if available.
*/
- (NSString *) countryCode;

/*!	@method		locationID
	@abstract	Returns a string identifying where the device is connected to
				the computer.
	@discussion	The location ID is not guaranteed to be constant, and is not
				user-readable. It can be used to distinguish between multiple
				similar devices on the same system when the serial number is
				not available.
*/
- (NSString *) locationID;

/*!	@method		transport
	@abstract	The method by which the device is connected to the computer.
	@discussion	Although the HID specification is a USB specification, IOKit
				allows HID drivers to be defined for arbitrary devices. In
				practice, HID devices can be USB devices, Bluetooth devices,
				ADB devices or PS/2 devices. (PowerPC portables have ADB
				keyboards, MacBooks have PS/2 trackpads.) Other transports,
				such as FireWire or as yet unknown protocols, are also possible.
				Actual observed values: "USB", "Bluetooth", "ADB", "PS2".
				When using the transport value (for instance, for uniquely
				identifying devices, or badging in UIs) it is suggested that
				you use case-insensitive comparsion, and be prepared for
				unknown strings and nil.
*/
- (NSString *) transport;

- (JAHIDUsagePage) primaryUsagePage;
- (JAHIDUsage) primaryUsage;
- (NSArray *) usages;	// List of dictionaries, with the keys kJAHIDDeviceUsagePage and kJAHIDDeviceUsage

@end


extern NSString * const kJAHIDDeviceUsagePage;
extern NSString * const kJAHIDDeviceUsage;

extern NSString * const kJAHIDDeviceAddedNotification;
extern NSString * const kJAHIDDeviceRemovedNotification;
